import { join } from "path";
import { Collection, REST, Routes } from "discord.js";
import getAllFiles from "@bot/utils/getAllFiles";
import Interaction from "@bot/components/interaction";
import DiscordBot from "@bot/bot";

export default class InteractionHandler extends Collection<string, Interaction> {
    readonly client: DiscordBot;

    constructor(client: DiscordBot) {
        super();
        this.client = client;
        this.init();
    }

    private async init() {
        const interactionsDirectory = join(__dirname, "../interactions");
        const modules = getAllFiles(interactionsDirectory);

        for (const module of modules) {
            const imported = await import(module);
            const interactionClass = imported.default || imported;
            const interaction: Interaction = new interactionClass(this.client);
            this.set(interaction.name, interaction);
        }
    }

    async deploy() {
        const interactions = this.map(inter => inter.toJSON())
        const rest = new REST({ version: "10" }).setToken(process.env.BOT_TOKEN!);

        for (const guild of this.client.guilds.cache.values()) {
            rest.put(
                Routes.applicationGuildCommands(process.env.CLIENT_ID!, guild.id),
                { body: interactions }
            )
        }
    }
}
