import fs from "fs";
import { join } from "path";

/**
 * Recursively gets all .ts or .js files in a directory and its subdirectories.
 * @param directoryPath - The directory to start from.
 * @param existingResult - Optional array to accumulate results.
 * @returns A list of full paths to .ts or .js files.
 */
const getAllFiles = (directoryPath: string, existingResult?: string[]) => {
    const fileNames = fs.readdirSync(directoryPath);
    const result: string[] = existingResult ?? [];

    for (const fileName of fileNames) {
        const fullPath = join(directoryPath, fileName);
        const stat = fs.statSync(fullPath);

        if (stat.isDirectory()) {
            getAllFiles(fullPath, result);
        } else if (fileName.endsWith(".ts") || fileName.endsWith(".js")) {
            result.push(fullPath);
        }

    }

    return result;
};

export default getAllFiles;